# S5 Sequence Mixer

::: linax.sequence_mixers.s5.S5SequenceMixerConfig
    options:
      members:
        - build

---

::: linax.sequence_mixers.s5.S5SequenceMixer
    options:
      members:
        - __init__
        - __call__
